@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: hlint
 version: 1.9.32
-id: hlint-1.9.32-90db989eb30a130842bd3014d63efdf6
-key: hlint_8xWLgFPgd4c16qowRhXdfy
+id: hlint-1.9.32-31079866b36e567047a82f996466a433
+key: hlint_4pYEiBqZxjeGWs2eh58FmK
 license: BSD3
 copyright: Neil Mitchell 2006-2016
 maintainer: Neil Mitchell <ndmitchell@gmail.com>
@@ -29,17 +29,17 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/hlint-1.9.32
 library-dirs: /usr/lib/ghc-7.10.3/site-local/hlint-1.9.32
 data-dir: /usr/share/hlint
-hs-libraries: HShlint-1.9.32-8xWLgFPgd4c16qowRhXdfy
+hs-libraries: HShlint-1.9.32-4pYEiBqZxjeGWs2eh58FmK
 depends:
     ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     cmdargs-0.10.14-ea4d1877c8c5fa6ed8eebd52f962ac3b
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cpphs-1.20.1-b531b91e3eedabd84a3f357cbe12d473
+    cpphs-1.20.1-871062ee45047e2f85948c7199a03a26
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
-    extra-1.4.3-ab419342055a04bda9f8a7a264d348c1
+    extra-1.4.5-10077f7db37a9e7a9a4966b0deb2b4e1
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
-    haskell-src-exts-1.17.1-22ac2cdd01c70a173d0a3e75bc933334
+    haskell-src-exts-1.17.1-a439f7709447829586f6c45dee78a187
     hscolour-1.24-b1fe788d8499aec980e06c0cdcf38b18
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
     refact-0.3.0.2-cdc0b885b64467c207c7798e46520776
